module WebFrontendBinect
    class ApplicationController < ActionController::Base
        protect_from_forgery with: :exception

        before_action :set_locale

        NotAuthorised = Class.new(StandardError)

        rescue_from WebFrontendBinect::ApplicationController::NotAuthorised do
            redirect_to "/"
        end

        def set_locale
            # User locale via ?locale=de param
            I18n.locale = params[:locale] # || I18n.default_locale

            # Use locale from browser of default as fallback
            I18n.locale = extract_locale_from_accept_language_header if I18n.locale.nil?
        end

        private
        def extract_locale_from_accept_language_header
            if ( request.env['HTTP_ACCEPT_LANGUAGE'].nil? )
                return I18n.default_locale
            end
            request.env['HTTP_ACCEPT_LANGUAGE'].scan(/^[a-z]{2}/).first
        end

    end
end
